Learn R Programming

EFAfactors (version 1.2.4)

data.scaler.DNN: the Scaler for the pre-trained Deep Neural Network (DNN)

Description

This dataset contains the means and standard deviations of the 10,000,000 datasets for training the Deep Neural Network (DNN), which can be used to determine the number of factors.

Arguments

Format

A list containing two vectors, each of length 54:

means

A numeric vector representing the means of the 54 features extracted from the 10,000,000 datasets.

sds

A numeric vector representing the standard deviations of the 54 features extracted from the 10,000,000 datasets.

See Also

NN, load.scaler, data.datasets.DNN, normalizor

Examples

Run this code
data(data.scaler.DNN)
print(data.scaler.DNN)

data.scaler <- load.scaler(model="DNN")
print(data.scaler)

Run the code above in your browser using DataLab