Learn R Programming

EFAfactors (version 1.2.4)

load.NN: Load the the pre-trained Neural Networks for Determining the Number of Factors

Description

Loads the pre-trained Deep Neural Network (DNN) from the DNN.onnx or Long Short Term Memory (LSTM) Network form LSTM.onnx. The function uses the reticulate package to import the onnxruntime Python library and create an inference session for the model.

Usage

load.NN(model = "DNN")

Value

An ONNX runtime inference session object for the DNN or LSTM model.

Arguments

model

A character string indicating the model type. Possible values are "DNN" (default) or "LSTM".

See Also

NN