Learn R Programming

EFAfactors (version 1.2.4)

load.scaler: Load the Scaler for the pre-trained Neural Networks for Determining the Number of Factors

Description

Loads the scaler object within the EFAfactors package. This object is a list containing a mean vector and a standard deviation vector, which were computed from the 10,000,000 datasets data.datasets.DNN training the Deep Neural Network (DNN) or the 1,000,000 datasets data.datasets.LSTM training the Long Short Term Memory (LSTM) Network. It serves as a tool for normalizing features in NN.

Usage

load.scaler(model = "DNN")

Value

scaler objective.

Arguments

model

A character string indicating the model type. Possible values are "DNN" (default) or "LSTM".

See Also

NN, normalizor, data.scaler.DNN, data.scaler.LSTM

Examples

Run this code
library(EFAfactors)

scaler <- load.scaler()
print(scaler)


Run the code above in your browser using DataLab