Prints a brief summary of an object of class EFAscreet. This function will display the scree plot
of the eigenvalues when called, providing a visual representation of the factor analysis results.
# S3 method for EFAscreet
print(x, ...)None. This function is used for side effects (printing).
An object of class EFAscreet, which contains the eigenvalues from the factor analysis.
Additional arguments to be passed to the plotting function.